Miro
----

Create your app here and acquire Client ID and Client Secret
    https://miro.com/app/settings/user-profile/apps

Development callback URL
    http://localhost:8000/accounts/miro/login/callback/
